@@ -11,8 +11,9 @@ use Test2::API::Instance();
 # Preload some key event types
 my %LOADED = (
     map {
-        require "Test2/Event/$_.pm";
-        my $pkg = "Test2::Event::$_";
+        my $pkg  = "Test2::Event::$_";
+        my $file = "Test2/Event/$_.pm";
+        require $file unless $INC{$file};
         ( $pkg => $pkg, $_ => $pkg )
     } qw/Ok Diag Note Plan Bail Exception Waiting Skip Subtest/
 );
@@ -23,9 +24,8 @@ use Test2::Util::HashBase qw{
 
 # Private, not package vars
 # It is safe to cache these.
-my $INST       = Test2::API::Instance::_internal_use_only_private_instance();
-my $ON_RELEASE = $INST->context_release_callbacks;
-my $CONTEXTS   = $INST->contexts;
+my $ON_RELEASE = Test2::API::_context_release_callbacks_ref();
+my $CONTEXTS   = Test2::API::_contexts_ref();
 
 sub init {
     confess "The 'trace' attribute is required"
